==> logicmonitor_sdk-python-1.0.115.tar.gz: python/docs/CollectorBase.md <==
# CollectorBase

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**user_change_on** | **int** | The last time the Collector was updated, in epoch format | [optional] 
**conf_version** | **str** | The version of the agent.conf configuration file | [optional] 
**updated_on_local** | **str** | The time that the Collector was last updated, in local time format | [optional] 
**hostname** | **str** | The hostname of the device the Collector is installed on | [optional] 
**number_of_instances** | **int** |  | [optional] 
**id** | **int** | The id of the Collector | [optional] 
**ea** | **bool** | Whether the collector is in EA version | [optional] 
**watchdog_updated_on_local** | **str** | The time that the Collector Watchdog was last updated, in local time format | [optional] 
**has_fail_over_device** | **bool** | Whether the collector has failover devices | [optional] 
**collector_group_name** | **str** | The name of the group the Collector is in | [optional] 
**netscan_version** | **str** | The Netscan version associated with the Collector | [optional] 
**in_sdt** | **bool** | The SDT status of the collector | [optional] 
**updated_on** | **int** | The time that the Collector was last updated, in epoch format | [optional] 
**automatic_upgrade_info** | [**AutomaticUpgradeInfo**](AutomaticUpgradeInfo.md) | The details of the Collector&#39;s automatic upgrade schedule, if one exists | [optional] 
**number_of_hosts** | **int** | The number of devices monitored by the Collector | [optional] 
**collector_conf** | **str** | The Collector&#39;s configuration file | [optional] 
**sbproxy_conf** | **str** | The Proxy&#39;s configuration | [optional] 
**last_sent_notification_on_local** | **str** | The time that a notification was last sent for this Collector, in local time format | [optional] 
**custom_properties** | [**list[NameAndValue]**](NameAndValue.md) | The custom properties defined for the Collector | [optional] 
**predefined_config** | **object** | Collector configurations | [optional] 
**onetime_upgrade_info** | [**OnetimeUpgradeInfo**](OnetimeUpgradeInfo.md) | The details of the Collector&#39;s one time upgrade, if one has been scheduled | [optional] 
**wrapper_conf** | **str** | The java service wrapper&#39;s configuration | [optional] 
**clear_sent** | **bool** | Whether or not an alert clear notifcation has been sent for this Collector | [optional] 
**status** | **int** | The registration status of the Collector. Acceptable values are: 0&#x3D; unregistered, 1&#x3D; registered, 2&#x3D; stopped, 3&#x3D; suspended | [optional] 
**backup_agent_id** | **int** | The Id of the backup Collector assigned to the Collector | [optional] 
**specified_collector_device_group_id** | **int** | The device group id when create a new collector device | [optional] 
**escalating_chain_id** | **int** | The Id of the escalation chain associated with this Collector | [optional] 
**collector_size** | **str** | The size of the collector | [optional] 
**acked_on_local** | **str** | The time that the Collector was acknowledged (if it is in alert), in local time format | [optional] 
**watchdog_conf** | **str** | The Watchdog&#39;s configuration | [optional] 
**description** | **str** | The Collector&#39;s description | [optional] 
**created_on** | **int** | The time that the Collector was created, in epoch format | [optional] 
**platform** | **str** | The OS of the Collector device (e.g. Linux, Windows) | [optional] 
**is_down** | **bool** | Whether or not the Collector is currently down | [optional] 
**user_visible_hosts_num** | **int** | The number of devices monitored by the Collector and visible to the user that made the query | [optional] 
**can_downgrade** | **bool** | Whether the collector can be downgraded to a lower version | [optional] 
**ack_comment** | **str** | The comment associated with the Collector acknowledgement (if it is in alert and acknowledged) | [optional] 
**next_upgrade_info** | [**NextUpgradeInfo**](NextUpgradeInfo.md) | The details of the Collector&#39;s next upgrade, if one has been scheduled | [optional] 
**suppress_alert_clear** | **bool** | Whether alert clear notifications are suppressed for the Collector | [optional] 
**next_recipient** | **int** | The Id of the next recipient to which alert notifications will be sent | [optional] 
**acked_on** | **int** | The epoch at which the Collector was acknowledged (if it is in alert) | [optional] 
**user_change_on_local** | **str** | The last time the Collector was updated, in the account time zone | [optional] 
**collector_device_id** | **int** | The device id of the collector device | [optional] 
**acked_by** | **str** | The user that acknowledged the Collector (if it is in alert) | [optional] 
**user_permission** | **str** | The permission level of the user that made the API request to get Collector information | [optional] 
**need_auto_create_collector_device** | **bool** | Whether to create a collector device when instance collector | [optional] 
**watchdog_updated_on** | **int** | The time that the Watchdog Services was last updated, in epoch format | [optional] 
**can_downgrade_reason** | **str** | The reason why the collector can be downgraded | [optional] 
**last_sent_notification_on** | **int** | The time, in epoch format, that a notification was last sent for the Collector | [optional] 
**acked** | **bool** | Whether or not the Collector is currently acknowledged | [optional] 
**onetime_downgrade_info** | [**OnetimeUpgradeInfo**](OnetimeUpgradeInfo.md) | The details of the Collector&#39;s automatic downgrade schedule, if one exists | [optional] 
**up_time** | **int** | The time the Collector has been up, in seconds | [optional] 
**build** | **str** | The Collector version | [optional] 
**previous_version** | **str** | The previous version of the collector, used for downgrading | [optional] 
**collector_group_id** | **int** | The Id of the group the Collector is in | [optional] 
**created_on_local** | **str** | The time that the Collector was created, in local time format | [optional] 
**enable_fail_back** | **bool** | Whether or not automatic failback is enabled for the Collector | [optional] 
**resend_ival** | **int** | The interval, in minutes, after which alert notifications for the Collector will be resent | [optional] 
**arch** | **str** | The collector architecture (Windows | Linux platform followed by 32 | 64 bit) | [optional] 
**enable_fail_over_on_collector_device** | **bool** | Whether or not the device the Collector is installed on is enabled for fail over | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

==> logicmonitor_sdk-python-1.0.122.tar.gz: python/docs/CollectorBase.md <==
# CollectorBase

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**user_change_on** | **int** | The last time the Collector was updated, in epoch format | [optional] 
**conf_version** | **str** | The version of the agent.conf configuration file | [optional] 
**updated_on_local** | **str** | The time that the Collector was last updated, in local time format | [optional] 
**hostname** | **str** | The hostname of the device the Collector is installed on | [optional] 
**number_of_instances** | **int** |  | [optional] 
**id** | **int** | The id of the Collector | [optional] 
**ea** | **bool** | Whether the collector is in EA version | [optional] 
**watchdog_updated_on_local** | **str** | The time that the Collector Watchdog was last updated, in local time format | [optional] 
**has_fail_over_device** | **bool** | Whether the collector has failover devices | [optional] 
**collector_group_name** | **str** | The name of the group the Collector is in | [optional] 
**netscan_version** | **str** | The Netscan version associated with the Collector | [optional] 
**in_sdt** | **bool** | The SDT status of the collector | [optional] 
**updated_on** | **int** | The time that the Collector was last updated, in epoch format | [optional] 
**automatic_upgrade_info** | [**AutomaticUpgradeInfo**](AutomaticUpgradeInfo.md) | The details of the Collector&#39;s automatic upgrade schedule, if one exists | [optional] 
**number_of_hosts** | **int** | The number of devices monitored by the Collector | [optional] 
**collector_conf** | **str** | The Collector&#39;s configuration file | [optional] 
**sbproxy_conf** | **str** | The Proxy&#39;s configuration | [optional] 
**last_sent_notification_on_local** | **str** | The time that a notification was last sent for this Collector, in local time format | [optional] 
**custom_properties** | [**list[NameAndValue]**](NameAndValue.md) | The custom properties defined for the Collector | [optional] 
**predefined_config** | **object** | Collector configurations | [optional] 
**onetime_upgrade_info** | [**OnetimeUpgradeInfo**](OnetimeUpgradeInfo.md) | The details of the Collector&#39;s one time upgrade, if one has been scheduled | [optional] 
**wrapper_conf** | **str** | The java service wrapper&#39;s configuration | [optional] 
**clear_sent** | **bool** | Whether or not an alert clear notifcation has been sent for this Collector | [optional] 
**status** | **int** | The registration status of the Collector. Acceptable values are: 0&#x3D; unregistered, 1&#x3D; registered, 2&#x3D; stopped, 3&#x3D; suspended | [optional] 
**backup_agent_id** | **int** | The Id of the backup Collector assigned to the Collector | [optional] 
**specified_collector_device_group_id** | **int** | The device group id when create a new collector device | [optional] 
**escalating_chain_id** | **int** | The Id of the escalation chain associated with this Collector | [optional] 
**collector_size** | **str** | The size of the collector | [optional] 
**acked_on_local** | **str** | The time that the Collector was acknowledged (if it is in alert), in local time format | [optional] 
**watchdog_conf** | **str** | The Watchdog&#39;s configuration | [optional] 
**description** | **str** | The Collector&#39;s description | [optional] 
**created_on** | **int** | The time that the Collector was created, in epoch format | [optional] 
**platform** | **str** | The OS of the Collector device (e.g. Linux, Windows) | [optional] 
**is_down** | **bool** | Whether or not the Collector is currently down | [optional] 
**user_visible_hosts_num** | **int** | The number of devices monitored by the Collector and visible to the user that made the query | [optional] 
**can_downgrade** | **bool** | Whether the collector can be downgraded to a lower version | [optional] 
**ack_comment** | **str** | The comment associated with the Collector acknowledgement (if it is in alert and acknowledged) | [optional] 
**next_upgrade_info** | [**NextUpgradeInfo**](NextUpgradeInfo.md) | The details of the Collector&#39;s next upgrade, if one has been scheduled | [optional] 
**suppress_alert_clear** | **bool** | Whether alert clear notifications are suppressed for the Collector | [optional] 
**next_recipient** | **int** | The Id of the next recipient to which alert notifications will be sent | [optional] 
**acked_on** | **int** | The epoch at which the Collector was acknowledged (if it is in alert) | [optional] 
**user_change_on_local** | **str** | The last time the Collector was updated, in the account time zone | [optional] 
**collector_device_id** | **int** | The device id of the collector device | [optional] 
**acked_by** | **str** | The user that acknowledged the Collector (if it is in alert) | [optional] 
**user_permission** | **str** | The permission level of the user that made the API request to get Collector information | [optional] 
**need_auto_create_collector_device** | **object** | Whether to create a collector device when instance collector, the default value is true | [optional] 
**watchdog_updated_on** | **int** | The time that the Watchdog Services was last updated, in epoch format | [optional] 
**can_downgrade_reason** | **str** | The reason why the collector can be downgraded | [optional] 
**last_sent_notification_on** | **int** | The time, in epoch format, that a notification was last sent for the Collector | [optional] 
**acked** | **bool** | Whether or not the Collector is currently acknowledged | [optional] 
**onetime_downgrade_info** | [**OnetimeUpgradeInfo**](OnetimeUpgradeInfo.md) | The details of the Collector&#39;s automatic downgrade schedule, if one exists | [optional] 
**up_time** | **int** | The time the Collector has been up, in seconds | [optional] 
**build** | **str** | The Collector version | [optional] 
**previous_version** | **str** | The previous version of the collector, used for downgrading | [optional] 
**collector_group_id** | **int** | The Id of the group the Collector is in | [optional] 
**created_on_local** | **str** | The time that the Collector was created, in local time format | [optional] 
**enable_fail_back** | **object** | Whether or not automatic failback is enabled for the Collector, the default value is true | [optional] 
**resend_ival** | **int** | The interval, in minutes, after which alert notifications for the Collector will be resent | [optional] 
**arch** | **str** | The collector architecture (Windows | Linux platform followed by 32 | 64 bit) | [optional] 
**enable_fail_over_on_collector_device** | **bool** | Whether or not the device the Collector is installed on is enabled for fail over | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)
